@@ -73,7 +73,7 @@ use vars qw( $VERSION @ISA @EXPORT_OK %EXPORT_TAGS $debug %group_data
 use Carp qw(carp croak cluck);
 use base qw(Exporter);
 
-use Business::ISBN::Data 20140910.001; # now a separate module
+use Business::ISBN::Data 20140910.002; # now a separate module
 # ugh, hack
 *group_data = *Business::ISBN::country_data;
 sub _group_data { $group_data{ $_[1] } }
@@ -110,7 +110,7 @@ BEGIN {
 		);
 	};
 
-$VERSION = "2.09_02";
+$VERSION = "2.010_01";
 
 sub ARTICLE_CODE_OUT_OF_RANGE () { -5 }
 sub INVALID_PREFIX            () { -4 };
@@ -183,10 +183,11 @@ digit, 'x', or 'X'.
 The constructor attempts to determine the group code and the publisher
 code.  If these data cannot be determined, the constructor sets C<<
 $obj->error >> to something other than C<GOOD_ISBN>. An object is
-still returned and it is up to the program to check C<< $obj->error >>
-for one of five values (which may be exported on demand). The actual
+still returned and it is up to the program to check the C<< error >> method
+for one of five values or one of the C<< error_* >> methods to check for
+a particular error. The actual
 values of these symbolic versions are the same as those from previous
-versions of this module which used literal values.
+versions of this module which used literal values:
 
 
 	Business::ISBN::INVALID_PUBLISHER_CODE
@@ -197,10 +198,13 @@ versions of this module which used literal values.
 
 If you have one of these values and want to turn it into a string, you
 can use the C<%Business::ISBN::ERROR_TEXT> hash, which is exportable
-by asking for it explicitly in the import list.
+by asking for it explicitly in the import list:
 
 	use Business::ISBN qw(%ERROR_TEXT);
 
+As of version 2.010_01, you can get this text from C<< error_text >>
+so you don't have to import anything.
+
 The string passed as the ISBN need not be a valid ISBN as long as it
 superficially looks like one.  This allows one to use the
 C<fix_checksum()> method.  Despite the disclaimer in the discussion of
@@ -294,7 +298,43 @@ value is a key in %ERROR_TEXT.
 
 =cut
 
-sub error { $_[0]->{'valid'} }
+sub error { $_[0]->{'valid'} < 1 and $_[0]->{'valid'} }
+
+=item error_is_bad_group
+
+=item error_is_bad_publisher
+
+=item error_is_article_out_of_range
+
+=item error_is_bad_checksum
+
+Returns true if the ISBN error is that type.
+
+=cut
+
+sub error_is_bad_group {
+	return $_[0]->error == INVALID_GROUP_CODE;
+	}
+
+sub error_is_bad_publisher {
+	return $_[0]->error == INVALID_PUBLISHER_CODE;
+	}
+
+sub error_is_article_out_of_range {
+	return $_[0]->error == ARTICLE_CODE_OUT_OF_RANGE;
+	}
+
+sub error_is_bad_checksum {
+	return $_[0]->error == BAD_CHECKSUM;
+	}
+
+=item error_text
+
+Returns a text version of the error text
+
+=cut
+
+sub error_text { $ERROR_TEXT{$_[0]->{'valid'}} }
 
 =item is_valid
 
@@ -535,6 +575,8 @@ This feature requires C<LWP::Simple> or C<Mojo::UserAgent>.
 
 sub xisbn {
 	my $self = shift;
+	carp "The xisbn service was due to be turned off on March 15, 2016.";
+	carp "The xisbn method is deprecated.";
 
 	my $data = $self->_get_xisbn;
 	$data =~ tr/x/X/;
@@ -894,7 +936,7 @@ __END__
 
 This source is in Github:
 
-    https://github.com/briandfoy/business--isbn
+    https://github.com/briandfoy/business-isbn
 
 =head1 AUTHOR
 
