@@ -4,15 +4,6 @@ use base qw(Business::ISBN);
 
 use Business::ISBN qw(:all);
 
-use subs qw(
-	_checksum
-	INVALID_GROUP_CODE
-	INVALID_PUBLISHER_CODE
-	BAD_CHECKSUM
-	GOOD_ISBN
-	BAD_ISBN
-	);
-
 use vars qw(
 	$VERSION
 	$debug
@@ -24,7 +15,7 @@ use Carp qw(carp croak cluck);
 
 my $debug = 0;
 
-$VERSION   = '2.09_02';
+$VERSION   = '2.010_01';
 
 sub _max_length { 10 }
 
@@ -107,7 +98,7 @@ See L<Business::ISBN>
 
 This source is in Github:
 
-    https://github.com/briandfoy/business--isbn
+    https://github.com/briandfoy/business-isbn
 
 =head1 AUTHOR
 
